#!/bin/sh

CheckFiles()
{
  if test ! -d include
  then
    echo "Error: Could not find directory 'include'!"
    return 1;
  fi
   
  if test ! -d lib
  then
    echo "Error: Could not find directory 'lib'!"
    return 1;
  fi
  
  if test ! -d tbarcode
  then
    echo "Error: Could not find directory 'tbarcode'!"
    return 1;
  fi
  
  return 0;
}

InstallFiles()
{
  echo "Copying include files..."
  if test -d /usr/local/include
  then
    cp -R include/* /usr/local/include
    if test $? -ne 0
    then
      echo "Error: Could not copy files!"
      return 1;
    fi
  else
    echo "Error: Could not find /usr/local/include!"
    return 1
  fi

  echo "Copying libraries..."
  if test -d /usr/local/lib
  then
    cp -R lib/* /usr/local/lib
    if test $? -ne 0
    then
      echo "Error: Could not copy files!"
      return 1;
    fi
  else
    echo "Error: Could not find /usr/local/lib!"
    return 1
  fi
  
  echo "Copying tbarcode files..."
  mkdir -p /usr/local/share/tbarcode7
  if test -d /usr/local/share/tbarcode7
  then
    cp -R tbarcode/* /usr/local/share/tbarcode7
    if test $? -ne 0
    then
      echo "Error: Could not copy files!"
      return 1;
    fi
  else
    echo "Error: Could not create /usr/local/share/tbarcode7!"
    return 1
  fi
  return 0;
}

PostInstallationProcedure()
{
  echo "Registering TBarCode Library..."
  ln -s /usr/local/lib/libtbarcode7.so.0 /usr/local/lib/libtbarcode7.so
  /sbin/ldconfig /usr/local/lib
  if test $? -ne 0
  then
    echo "Error: ldconfig failed!"
    echo "Try to call 'ldconfig /usr/local/lib'"
  fi
  
  echo "Creating link for TBarCode executable..."
  ln -s /usr/local/share/tbarcode7/tbarcode /usr/bin/tbarcode
  if test $? -ne 0
  then
    echo "Warning: Could not create link to tbarcode!"
  fi
  return 0;
}

echo " TBarCode for Unix - Installation"
echo " --------------------------------"
echo ""

if CheckFiles && InstallFiles && PostInstallationProcedure
then    
  echo "Installation finished."
  exit 0
else
  echo "Installation aborted."
  exit 1
fi
